"""This is the “kimolo.py" module, and it provides one function called
print_lol() which prints lists that may or may not include nested lists."""
def print_lol(the_list):
    """This function takes a positional argument called “the_list", which is any
    Python list (of, possibly, nested lists). Each data item in the provided list
    is (recursively) printed to the screen on its own line."""
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            print(each_item)




from distutils.core import setup
setup(
        name = 'kimolo',
        version = '1.0.0',
        py_modules = ['kimolo'],
        author = 'dankim',
        author_email = 'dankimist@gmail.com',
        url = 'http://www.fb.com/kinduberr',
        description = 'A simple printer of nested lists',
     )
